<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:XSLUtils="com.esko.webcenter.jsp.XSLUtils" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="XSLUtils Lang">
	<xsl:import href="template.xsl"/>
	<xsl:import href="projwctasktemplates.xsl"/>
	<xsl:import href="attributetemplates.xsl"/>
 	<xsl:import href="projmgmntnewproject.xsl"/>   <!-- JANH then move the only common template "NewDocumentsSelector" to more general XSL file -->
 	<xsl:import href="doctemplates.xsl"/>
 	<xsl:import href="doctypetmplts.xsl"/>
	
	
	<xsl:variable name="useTableBodyContainer" select="false()" />
	
	

  <xsl:key name="projectStatusKey" match="/webcenter_page/project_status_list/custom_project_status" use="@id"/>
  
  <!-- Key path that leads to a User Member Role Assignment Data (contains Role Names of the assigned Roles)-->
  <xsl:key name="projUserMemberAssignmentDataKey" match="/webcenter_page/project_role_assignment_map_list/project_user_members_role_assignments_list/user" use="@id"/>
  <!-- Key path that leads to a Group Member Role Assignment Data (contains Role Names of the assigned Roles)-->
  <xsl:key name="projGroupMemberAssignmentDataKey" match="/webcenter_page/project_role_assignment_map_list/project_group_members_role_assignments_list/group" use="@id"/>

	<!-- global variables -->

	<!-- variable for debug purposes - fast switch between task execution and editation modes -->
 	<xsl:variable name="taskExecution" select="1"/>

	<!-- PMs and admins are not able to do more on TEP than ordinary users (in contrast to Task Details pages) -->
<!--   <xsl:variable name="isProjectEditable" select="/webcenter_page/is_project_editable = '1'" /> -->
  <xsl:variable name="isProjectEditable" select="0" />

 	<xsl:variable name="isProjActive" select="key('projectStatusKey',/webcenter_page/project/status_id)/is_active = '1'"/>
	<xsl:variable name="isProjectClosed" select="not($isProjActive)"/>   <!--JANH differs from task edit page!!! -->

	<!-- 	<xsl:variable name="isProjActive" select="0"/>   readonly variation -->

<!-- 	introduced because of workflow error status - but might be merged with other options later on -->
	<xsl:variable name="isTaskPageReadonly" select="/webcenter_page/is_task_page_readonly = '1'"/>

	<xsl:variable name="showSimpleGUI" select="/webcenter_page/showSimpleGUI = '1'"/>
		
	<xsl:variable name="isTaskEditable" select="(((/webcenter_page/is_task_editable = '1') and $isProjActive) or $isProjectEditable) and not($isTaskPageReadonly)" />
	<xsl:variable name="isTaskCompleted" select="/webcenter_page/project_wctask/is_complete = '1'"/>
	<!-- task is started if not just under creation process and if its status is not "created" -->
	<xsl:variable name="isTaskStarted" select="(/webcenter_page/project_wctask/status) and (/webcenter_page/project_wctask/status/@id != '00001_0000000001')"/>
	<xsl:variable name="changeTaskRightGranted" select="/webcenter_page/project_user_permissions/permission/change_task = '1'"/>
	<xsl:variable name="isAssigneeLoggedIn" select="/webcenter_page/is_current_user_assignee = '1'"/>
	<xsl:variable name="wouldBeNewValidAssignee" select="/webcenter_page/cur_user_would_be_valid_owner = '1'"/>
	<xsl:variable name="hasWorkflow" select="/webcenter_page/project_wctask/has_workflow != 0 and /webcenter_page/project_wctask/has_wfreport = 0"/>
	<xsl:variable name="isTemplate" select="/webcenter_page/project/is_template != 0"/>

	<xsl:variable name="isChangeable" select="$isTaskEditable and ($changeTaskRightGranted or $isAssigneeLoggedIn)"/>
	<xsl:variable name="isStatusEditable" select="(((/webcenter_page/is_task_status_editable = '1') and $isProjActive) or $isProjectEditable) and not($isTaskPageReadonly)"/>
	<!-- if user is direct assignee or member of group assignee and task is not complete -->
	<!-- and project (in which the task is) is active set 'canChangeAssignee' to true    -->
	<!-- this flag is important only if $isChangeable is false -->
	<xsl:variable name="canChangeAssignee" select="not($isTaskCompleted) and ($isProjActive or $isProjectEditable) and not($isTaskPageReadonly)"/>
		
	
	  <xsl:template name="bodyextensions">
	  </xsl:template>
	
  <!-- 
  
            template that controls the generation of the body header
            
  -->
  <xsl:template name="bodyheader">
	<xsl:call-template name="DisplayHeaderAction"/>
  </xsl:template>
  
  
	<!-- 
            
		Template that controls the generation of the body content
            
	-->
	<xsl:template name="bodycontent">

<!-- JANH for debug use 
isTaskEditable: <xsl:value-of select="$isTaskEditable"/><br/>
===============================<br/>
isProjActive: <xsl:value-of select="$isProjActive"/><br/>
isProjectClosed: <xsl:value-of select="$isProjectClosed"/><br/>

isTaskStarted: <xsl:value-of select="$isTaskStarted"/><br/>
isTaskCompleted: <xsl:value-of select="$isTaskCompleted"/><br/>
isChangeable: <xsl:value-of select="$isChangeable"/><br/>
isStatusEditable: <xsl:value-of select="$isStatusEditable"/><br/>
canChangeAssignee: <xsl:value-of select="$canChangeAssignee"/><br/>
 -->

	<xsl:choose>
		<xsl:when test="/webcenter_page/is_valid_owner = '1' or $isTaskCompleted">
			<div id="messageRowId">
				<xsl:call-template name="DisplayNotification">
				</xsl:call-template>

				<xsl:call-template name="DisplayAttrSaveNotification">
					<xsl:with-param name="addTableRow" select="false()"/>
				</xsl:call-template>
			</div>
		</xsl:when>
		<xsl:otherwise>
			<xsl:variable name="curAssigneeName"><xsl:value-of select="/webcenter_page/project_wctask/task_owner_name"/></xsl:variable>
			<xsl:variable name="mainAssigneeName"><xsl:value-of select="/webcenter_page/main_assignee"/></xsl:variable>
							
			<div class="alert alert-warning alert-dismissible" role="alert">
				<button type="button" class="close" data-dismiss="alert" aria-label="Close"><i class="icon icon-small icon-WCR_Close12"></i></button>
					<xsl:value-of select="Lang:getStr(&lk;,'WCTASK_INVALID_ASSIGNED_DUE_TO_MAIN_ASSIGNEE',$curAssigneeName,$mainAssigneeName,$mainAssigneeName)"/>
			</div>
		</xsl:otherwise>
	</xsl:choose>
	
				<form name="actionform" id="actionformId" method="post" enctype="MULTIPART/FORM-DATA" action="doprojectwctask.jsp" class="wcr-form">
					<input type="hidden" name="actionVal" id="actionValId" value="ChangeTaskOnExecutionPage"/>
<!-- 					serves to decide, if the cancel/return button would work as return - so return to previous(source) page, or as a cancel - just wipe changes and stay on the TEP page  -->
					<input type="hidden" name="pageModified" id="pageModifiedId" value="0"/>
			    			    
					<xsl:variable name="taskTypeDocAttrCat" select="/webcenter_page/wctask_type_list/wctask_type_view/wctask_type/documents_section/def_doc_attrs_cat_id" />
					<xsl:if test="$taskTypeDocAttrCat != ''">
						<input type="hidden" name="fixeDocumentAttributeCategory" id="fixeDocumentAttributeCategory" value="{$taskTypeDocAttrCat}"/>
					</xsl:if>
					
			    <xsl:call-template name="menuFileHiddenInput"/>
    			<input name="projectID" value="{/webcenter_page/project/@id}" type="hidden"/>
			    <input name="projectTaskID" value="{/webcenter_page/project_wctask/@id}" type="hidden"/>
			    
					<input name="projectTaskName" value="{/webcenter_page/project_wctask/name}" type="hidden"/>
				  					
				  <!-- auxiliary field to distinguish between limited and fully editable GUI versions -->
				  <input type="hidden" name="completeForm" value="{$isChangeable}"/>
					
					<!-- auxiliary field to pass what sections were modified to TaskActionsHelper.java -->
					<input type="hidden" name="modifiedSections" id="modifiedSections" value=""/>
					
					<div class="form-section">
					
					<xsl:choose>
						<xsl:when test="/webcenter_page/is_valid_owner = '1' or $isTaskCompleted">
							
										<div id="mainTableId">
											
											<div id="upperButtonRow">
													<xsl:call-template name="MainButtons"/>
											</div>
											
											<div class="form-group" id="LoadingRowId">
												<label class="offset-label"/>
												<div class="form-entry">
													<p><xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_LOADING')"/></p>
												</div>
											</div>
		
											<div id="descriptionRow" class="displayNone">
													<xsl:call-template name="ProjectWcTaskDescriptionRow">
														<xsl:with-param name="isEditable" select="0"/>
													</xsl:call-template>
											</div>
		 									
											<div id="mainWcTaskInfoRowId" class="displayNone">
													<div id="taskDetailsBlockId">
														<xsl:call-template name="ProjectWcTaskGenInfoShort" />
													</div>
											</div>
											
											<div id="mainAttributesDetailsRowId" style="display:none;"  class="displayNone">
												<div class="form-group">
													<label class="offset-label"></label>
													<div class="form-entry full-width">
													<xsl:call-template name="MainTaskAttributesDetails"/>
													</div>
												</div>
											</div>
											
											<div id="mainDocumentsDetailsRowId" style="display:none;"  class="displayNone">
												<div class="form-group">
													<label class="offset-label"></label>
													<div class="form-entry full-width">
													<xsl:call-template name="MainTaskDocumentsDetails"/>
													</div>
												</div>
											</div>
											
											<div id="mainChecklistDetailsRowId" style="display:none;"  class="displayNone">
												<div class="form-group">
													<label class="offset-label"></label>
													<div class="form-entry full-width">
													<xsl:call-template name="MainChecklistDetails"/>
													</div>
												</div>
											</div>
											
											<div id="mainDiscussionDetailsRowId" style="display:none;"  class="displayNone">
												<div class="form-group">
													<label class="offset-label"></label>
													<div class="form-entry full-width">
													<xsl:call-template name="MainDiscussionDetails"/>
													</div>
												</div>
											</div>
											
											<div id="lowerButtonRow" style="display:none;"  class="displayNone">
													<xsl:call-template name="MainButtons"/>
											</div>
											
										</div>
											
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="mainAssigneeName"><xsl:value-of select="/webcenter_page/main_assignee"/></xsl:variable>
							
							<div class="form-group">
								<input type="hidden" name="forceAssignToMainAssignee" value="true"/>
								<input type="hidden" name="taskAssignee">
									<!-- Task owner will always be a role or group -->
									<xsl:attribute name="value">G<xsl:value-of select="/webcenter_page/main_assignee_id"/></xsl:attribute>
								</input> 
								
								<label class="offset-label"></label>
								<div class="form-entry">
									<input type="submit" class="btn btn-primary">
									<xsl:attribute name="value">
										<xsl:value-of select="Lang:getStr(&lk;,'WCTASK_ASSIGN_TO', $mainAssigneeName)"/>
									</xsl:attribute>
								</input>
							</div>
							</div>
						</xsl:otherwise>
					</xsl:choose>
					
					</div>
				</form>
			
	</xsl:template>


<!-- Get the type of assignee, either Me, User, Group, Role or Unassigned.
	This method is used for the initial value of the Task Assignee drop down -->
<xsl:template name="CurrentAssigneeType">
	<!-- Check the Assignee type: ME, User, Group , Role or Unassigned -->
	<xsl:choose>
		<xsl:when test="project_wctask/user/@id and project_wctask/user/@id=/webcenter_page/loginuserid "><xsl:value-of select="'ME'"/></xsl:when>
		<xsl:when test="project_wctask/user/@id"><xsl:value-of select="'USER'"/></xsl:when>
		<xsl:when test="project_wctask/group/@id">
			<xsl:choose>
				<xsl:when test="project_wctask/group/is_role = '1'"><xsl:value-of select="'ROLE'"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="'GROUP'"/></xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise><xsl:value-of select="'UNASSIGNED'"/></xsl:otherwise>
	</xsl:choose>
	
</xsl:template>

<!-- Get the current Task Assignee display name : <Assignee Name> '<' <Type name - translated> '>'  -->
<xsl:template name="CurrentAssigneeDisplayName">
	<xsl:param name="AssigneeType"/>
						
		<xsl:choose>
			<xsl:when test="$AssigneeType= 'ME'"><xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_ASSIGNTOMYSELF')"/></xsl:when>
			<xsl:when test="$AssigneeType= 'USER'">
				<xsl:call-template name="DisplayUserName">
					<xsl:with-param name="userID" select="project_wctask/user/@id"/>
					<xsl:with-param name="lastName" select="project_wctask/user/last_name"/>
					<xsl:with-param name="firstName" select="project_wctask/user/first_name"/>
					<xsl:with-param name="loginName" select="project_wctask/user/name"/>
				</xsl:call-template>&nbsp;&lt;<xsl:value-of select="Lang:getStr(&lk;,'USER')"/>&gt;
			</xsl:when>
			<xsl:when test="$AssigneeType= 'GROUP' or $AssigneeType= 'ROLE'">
					<xsl:call-template name="DisplayGroupName">
						<xsl:with-param name="groupID" select="project_wctask/group/@id"/>
						<xsl:with-param name="groupName" select="project_wctask/group/name"/>
					</xsl:call-template>&nbsp;
					&lt;<xsl:choose><xsl:when test="project_wctask/group/is_role = '1'"><xsl:value-of select="Lang:getStr(&lk;,'ROLE')"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="Lang:getStr(&lk;,'GROUP')"/></xsl:otherwise>
					</xsl:choose>&gt;
			</xsl:when>
			<xsl:when test="$AssigneeType= 'UNASSIGNED'">&lt;<xsl:value-of select="Lang:getStr(&lk;,'NOBODY_TAG')"/>&gt;</xsl:when>
		</xsl:choose>
						
	</xsl:template>
							
<!-- Get the current Task Assignee display name : <Assignee Name> '<' <Type name - translated> '>'  -->
<xsl:template name="CurrentAssigneeValue">
	<xsl:param name="AssigneeType"/>
						
		<xsl:choose>
			<xsl:when test="$AssigneeType= 'ME'"><xsl:value-of select="'current_user'"/></xsl:when>
			<xsl:when test="$AssigneeType= 'USER'">U<xsl:value-of select="project_wctask/user/@id"/></xsl:when>
			<xsl:when test="$AssigneeType= 'GROUP' or $AssigneeType= 'ROLE'">R<xsl:value-of select="project_wctask/group/@id"/></xsl:when>
			<xsl:when test="$AssigneeType= 'UNASSIGNED'"><xsl:value-of select="'nobody'"/></xsl:when>
		</xsl:choose>
						
	</xsl:template>

	
	<!--
		Template to display the header
	-->
	<xsl:template name="DisplayHeaderAction">
		<div class="page-header">
			<h1>
				<div class="header-action-buttons">
						<!-- the link to open project details in a new window -->
						<xsl:if test="not($showSimpleGUI)">
						<a class="btn btn-default">
									<xsl:attribute name="href">
										<xsl:value-of select="'projdetails.jsp?projectID='"/>
										<xsl:value-of select="/webcenter_page/project_wctask/project_id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>
									</xsl:attribute>
									<xsl:value-of select="Lang:getStr(&lk;,'PROJECT_DETAILS_TAG')"/>
								</a>
					</xsl:if>
					
					<!-- the link to edit task details page is accessible only to users with "change task" permission	-->
					<xsl:if test="$changeTaskRightGranted and not($showSimpleGUI)">
						<a class="btn btn-primary" href="#" onclick="window.taskExPage.editTaskDetailsClicked();">
							<xsl:value-of select="Lang:getStr(&lk;,'EDIT_WCTASK_DETAILS_TAG')"/>
						</a>
						</xsl:if>
				</div>
				<div class="actiontitlebar">
					<xsl:value-of select="Lang:getStr(&lk;,'TASK')"/>:&nbsp;
					<span class="font-weight-medium"><xsl:value-of select="/webcenter_page/project_wctask/name"/></span>
					&nbsp;&nbsp;
					<xsl:value-of select="Lang:getStr(&lk;,'PROJECT')"/>:&nbsp;
					<span class="font-weight-medium"><xsl:value-of select="/webcenter_page/project/name"/></span>
				</div>
			</h1>
		</div>
				
				
				<xsl:call-template name="SelectDocumentTemplateDialog"/>
		
	</xsl:template>

	
	<!--
		Main Buttons Section
	-->
	<xsl:template name="MainButtons">
		<!--  upper "Change" and "Cancel" buttons -->
		<div class="form-group">
			<label class="offset-label"></label>
			<div class="form-entry">
			
				<xsl:choose>
					<xsl:when test="$isChangeable or $isStatusEditable or $canChangeAssignee">
						<div class="" role="group">
			
							<!-- firefox needs submit button for actual submission -->
							<input type="submit" class="btn btn-default" style="display:none;" />
							
							<!-- Start Task button -->
							<xsl:if test="not($isTaskStarted) and $isChangeable and not($isTemplate)">
								<xsl:choose>
									<xsl:when test="$hasWorkflow">
										<input type="button" name="startWCTask" class="btn btn-primary"
											value="{Lang:getStr(&lk;,'START_WCTASK_WORKFLOW_TAG')}">
											<xsl:attribute name="onclick">window.taskExPage.startButtonClicked();</xsl:attribute>
										</input>
									</xsl:when>
									<xsl:otherwise>
										<input type="button" name="startWCTask" class="btn btn-primary"
											value="{Lang:getStr(&lk;,'START_WCTASK_TAG')}">
											<xsl:attribute name="onclick">window.taskExPage.startButtonClicked();</xsl:attribute>
										</input>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:if>
							
							<!-- Change button -->
							<input disabled="disabled" type="button" name="createWCTask"
								style="display:none;">
								<xsl:attribute name="onclick">window.taskExPage.changeButtonClicked();</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of
									select="Lang:getStr(&lk;,'SAVECHANGES')" /></xsl:attribute>
								<xsl:attribute name="class">
						    			<xsl:choose>
						    				<xsl:when test="$isTemplate">
						    					btn btn-primary
						    				</xsl:when>
						    				<xsl:otherwise>
						    					btn btn-default
						    				</xsl:otherwise>
						    			</xsl:choose>
						    		</xsl:attribute>
							</input>
			
							<!-- Cancel/Return button -->
							<input type="button" name="cancelButton">
								<xsl:attribute name="onclick">window.taskExPage.cancelButtonClicked();</xsl:attribute>
								<xsl:choose>
									<xsl:when test="$isTaskCompleted">
										<xsl:attribute name="value"><xsl:value-of
											select="Lang:getStr(&lk;,'RETURN')" /></xsl:attribute>
										<xsl:attribute name="class">btn btn-primary</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<!-- previously was 'cancel'. But improved TEP contains first return, 
											util there are changes made. Then it change to 'cancel'. Rather will leave 
											this redundancy here, it might still get different -->
										<xsl:attribute name="value"><xsl:value-of
											select="Lang:getStr(&lk;,'RETURN')" /></xsl:attribute>
										<xsl:attribute name="class">btn btn-default</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
							</input>
							
							<!-- Complete Task button -->
							<xsl:if
								test="not($isTaskCompleted) and $isChangeable and not($hasWorkflow) and not($isTemplate) and $wouldBeNewValidAssignee">
								<input type="button" name="completeWCTask"
									value="{Lang:getStr(&lk;,'COMPLETE_WCTASK_TAG')}">
									<xsl:attribute name="onclick">window.taskExPage.completeButtonClicked();</xsl:attribute>
									<xsl:attribute name="class">
							         		<xsl:choose>
							         			<xsl:when test="$isTaskStarted">
							         				btn btn-primary
							         			</xsl:when>
							         			<xsl:otherwise>
							         				btn btn-default
							         			</xsl:otherwise>
							         		</xsl:choose>
							         	</xsl:attribute>
								</input>
							</xsl:if>
						</div>
					</xsl:when>
					<xsl:otherwise>
						<!-- Back button -->
						<input type="button" name="cancelButton" class="btn btn-primary">
							<xsl:attribute name="onclick">window.taskExPage.cancelButtonClicked();</xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of
								select="Lang:getStr(&lk;,'BACK')" /></xsl:attribute>
						</input>
					</xsl:otherwise>
				</xsl:choose>
			
			</div>
		</div>
	</xsl:template>	

	<!--
	
	Template for display of a wctask description
	
 	 -->
	<xsl:template name="ProjectWcTaskDescriptionRow">
		<xsl:param name="isEditable"/>
		
		<!-- display task description only if there is something to show -->
		<xsl:if test="string-length(project_wctask/description) &gt; 0">
			<div class="form-group">
				<label for="taskDesc"><xsl:value-of select="Lang:getStr(&lk;,'DESCRIPTION')"/></label>
				<div class="form-entry">
					<xsl:choose>
					<xsl:when test="$isEditable">
						<textarea id="taskDesc" name="taskDesc" class="form-control">
							<xsl:attribute name="onkeyup">
								window.taskExPage.pageSections.genTaskInfo.modified = true;
								return imposeMaxLength(this, <xsl:value-of select="field_sizes/field_size[@key='projwctask.description']/@value"/>);
							</xsl:attribute>
							<xsl:attribute name="onchange">
								window.taskExPage.pageSections.genTaskInfo.modified = true;
								return imposeMaxLength(this, <xsl:value-of select="field_sizes/field_size[@key='projwctask.description']/@value"/>);
							</xsl:attribute>
							<xsl:if test="not($isChangeable)">
								<xsl:attribute name="readonly">readonly</xsl:attribute>
							</xsl:if>
							<xsl:value-of select="project_wctask/description"/>
						</textarea>
					</xsl:when>
					<xsl:otherwise>
						<input type="hidden" id="taskDesc" name="taskDesc" value="{project_wctask/description}"/>
						<p><xsl:value-of select="project_wctask/description"/></p>
					</xsl:otherwise>
					</xsl:choose>
				</div>
			</div>
		
		</xsl:if>
	</xsl:template>

		
	<!--
	
	Template for display of a short version of task general info
	
  	-->
	<xsl:template name="ProjectWcTaskGenInfoShort">
		
			  <!-- status -->
		<div class="form-group">
			<label for="taskStatusInput"><xsl:value-of select="Lang:getStr(&lk;,'TASKTYPEDETAILSSTATUS_TAG')"/></label>
			<div class="form-entry" id="tep_status">
				<select id="taskStatusInput" name="taskStatusInput" onchange="window.taskExPage.pageSections.genTaskInfo.modified = true;" class="form-control">
							<xsl:if test="not($isStatusEditable) or ($hasWorkflow and $isTaskStarted)">
								<xsl:attribute name="disabled">disabled</xsl:attribute>
							</xsl:if>
							<xsl:for-each select="wctask_type_list/wctask_type_view[@id = /webcenter_page/project_wctask/task_type_id]/status_list/task_type_status_view">
								<xsl:sort select="wc_status/display_order" data-type="number" order="ascending"/>
								<xsl:choose>
									<xsl:when test="$isTemplate and not(wc_status/@id = '00001_0000000001')">
									</xsl:when>
									<xsl:otherwise>
										<option value="{wc_status/@id}">
											<xsl:if test="wc_status/@id = /webcenter_page/project_wctask/status/@id">
												<xsl:attribute name="selected">selected</xsl:attribute>
											</xsl:if>
											<xsl:value-of select="wc_status/status_name"/>
										</option>	
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</select>
			</div>
		</div>
						

		<!-- Assignee SDrop -->
		<div class="form-group">
			<!--  Label -->
			<label for="taskOwner">
				<xsl:choose>
					<xsl:when test="$isTaskCompleted">
						<xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_COMPLETED_BY')"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_ASSIGNE_TO')"/>
					</xsl:otherwise>
				</xsl:choose>
			</label>
			<!-- Actual assignee -->
			<div class="form-entry" id="tep_assigned_to">
			<xsl:choose>
				<!-- Is the task assignee changeable? If not, only show the assignee name -->	
				<xsl:when test="not($canChangeAssignee or $isChangeable)">
					<!-- if task completed or just looking into read-only template - task assignee can't be changed -->
					<xsl:choose>
						<xsl:when test="project_wctask/user/@id">
							<!-- assignee is a user -->
							<xsl:call-template name="DisplayUserName">
								<xsl:with-param name="userID" select="project_wctask/user/@id"/>
								<xsl:with-param name="lastName" select="project_wctask/user/last_name"/>
								<xsl:with-param name="firstName" select="project_wctask/user/first_name"/>
								<xsl:with-param name="loginName" select="project_wctask/user/name"/>
								<xsl:with-param name="roleGroupNameList" select="key('projUserMemberAssignmentDataKey', project_wctask/user/@id)"/>
								<xsl:with-param name="displayIcon" select="1"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="project_wctask/group/@id">
							<!-- assignee is a group -->
							<xsl:call-template name="DisplayGroupName">
								<xsl:with-param name="groupID" select="project_wctask/group/@id"/>
								<xsl:with-param name="projectID" select="project_wctask/project_id"/>
								<xsl:with-param name="groupName" select="project_wctask/group/name"/>
								<xsl:with-param name="isRole" select="project_wctask/group/is_role"/>
								<xsl:with-param name="roleGroupNameList" select="key('projGroupMemberAssignmentDataKey', project_wctask/group/@id)"/>
								<xsl:with-param name="displayIcon" select="1"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<p><i><xsl:value-of select="Lang:getStr(&lk;,'NOBODY_TAG')"/></i></p>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
			
				<!-- Editable: show the SDrop -->
				<xsl:otherwise>
					<!-- flag whether currently logged in user is selected as assignee of the task -->
					<xsl:variable name="currentUserAssignee" select="(project_wctask/task_owner_id = /webcenter_page/loginuserid) and (project_wctask/task_owner_type = 'user')"/>
						
					<xsl:variable name="AssigneeType"><xsl:call-template name="CurrentAssigneeType"/></xsl:variable>	
					<xsl:variable name="AssigneeName">
						<xsl:call-template name="CurrentAssigneeDisplayName">
							<xsl:with-param name="AssigneeType"><xsl:value-of select="$AssigneeType"/></xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="AssigneeValue">
						<xsl:call-template name="CurrentAssigneeValue">
							<xsl:with-param name="AssigneeType"><xsl:value-of select="$AssigneeType"/></xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
			
							
						<!-- Here comes the SDrop -->
						<xsl:choose>
							<xsl:when test="/webcenter_page/cur_user_would_be_valid_owner = '1'">
								<div class="input-group">
						        	<select size="1" class="form-control" name="taskAssignee" id="taskAssigneeSDrop"
						        		onchange="taskExPage.pageSections.genTaskInfo.modified = true;">
						        								        	
						        		<!-- Set the initial assignee -->
						        		<xsl:if test="$AssigneeName">
						        			<option >
						        				<xsl:attribute name="value"><xsl:value-of select="$AssigneeValue"/></xsl:attribute>
						        				<xsl:value-of select="$AssigneeName"/>
						        			</option>						        			
						        		</xsl:if>
						        	</select>
						        	<!-- 'Assign To Me' Button-->
						        	  <span class="input-group-btn">
									    <button class="btn" type="button" onclick="window.taskExPage.assignToMeButtonClicked();">
						                    <i class="icon icon-WCR_User12 "></i>
						                </button>
						            </span>						            
						        </div>
						</xsl:when>
						<xsl:otherwise>
					        	<select size="1" class="form-control" name="taskAssignee" id="taskAssigneeSDrop" 
					        			onchange="taskExPage.pageSections.genTaskInfo.modified = true;">
					        		<!-- Set the initial assignee -->
					        		<xsl:if test="$AssigneeName">
					        			<option >
					        				<xsl:attribute name="value"><xsl:value-of select="$AssigneeValue"/></xsl:attribute>
					        				<xsl:value-of select="$AssigneeName"/>
					        			</option>
					        		</xsl:if>
					        	</select>
					    </xsl:otherwise>
					</xsl:choose> 
				</xsl:otherwise>
			</xsl:choose>
			</div>
		</div>
		
 		  <!-- previous assignee (owner) -->
			<xsl:if test="string-length(project_wctask/previous_task_owner_id) &gt; 0">
			<div class="form-group">
				<label><xsl:value-of select="Lang:getStr(&lk;,'SEARCH_PREV_PROJ_TASK_OWNER')"/></label>
										
				<div class="form-entry" id="tep_previous_assignee">
					<p>
						<xsl:choose>
						<xsl:when test="project_wctask/previous_owner/user/@id">
							<!-- assignee is a user -->
							<xsl:call-template name="DisplayUserName">
								<xsl:with-param name="userID" select="project_wctask/previous_owner/user/@id"/>
								<xsl:with-param name="lastName" select="project_wctask/previous_owner/user/last_name"/>
								<xsl:with-param name="firstName" select="project_wctask/previous_owner/user/first_name"/>
								<xsl:with-param name="loginName" select="project_wctask/previous_owner/user/name"/>
								<xsl:with-param name="roleGroupNameList" select="key('projUserMemberAssignmentDataKey', project_wctask/previous_owner/user/@id)"/>
								<xsl:with-param name="displayIcon" select="1"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="project_wctask/previous_owner/group/@id">
							<!-- assignee is a group -->
							<xsl:call-template name="DisplayGroupName">
								<xsl:with-param name="groupID" select="project_wctask/previous_owner/group/@id"/>
								<xsl:with-param name="projectID" select="project_wctask/project_id"/>
								<xsl:with-param name="groupName" select="project_wctask/previous_owner/group/name"/>
								<xsl:with-param name="isRole" select="project_wctask/previous_owner/group/is_role"/>
								<xsl:with-param name="roleGroupNameList" select="key('projGroupMemberAssignmentDataKey', project_wctask/task_owner_id)"/>
								<xsl:with-param name="displayIcon" select="1"/>
							</xsl:call-template>
						</xsl:when>
						</xsl:choose>
					</p>
				</div>
			</div>
			</xsl:if>

			<!-- due date -->
			<xsl:call-template name="DisplayTaskDate">
				<xsl:with-param name="isEditable" select="not($taskExecution) and $isChangeable"/>
				<xsl:with-param name="langString" select="'PROJ_TASK_DUE_DATE'"/>
				<xsl:with-param name="taskDate" select="/webcenter_page/due_date"/>
				<xsl:with-param name="taskDateRO" select="/webcenter_page/due_date/long_date"/>
				<xsl:with-param name="fieldName" select="'due_date'"/>
				<xsl:with-param name="PeriodOfDayFieldName" select="'due_periodOfDay'" />
				<xsl:with-param name="className" select="'darktext_darklink_bold_12'"/>
				<xsl:with-param name="valueClassName" select="'darktext_darklink_bold_11'"/>
				<xsl:with-param name="onChangeMethod" select="'window.taskExPage.pageSections.genTaskInfo.dueDateChanged'"/>		
				<xsl:with-param name="id" select="'tep_due'"/>						
			</xsl:call-template>

			<!-- estimated date / completed date -->
			<xsl:choose>
			<xsl:when test="$isTaskCompleted">
				<!-- completed date -->
				<xsl:call-template name="DisplayTaskDate">
					<xsl:with-param name="isEditable" select="false()"/>
					<xsl:with-param name="langString" select="'PROJ_TASK_COMPLETED_DATE'"/>
					<xsl:with-param name="taskDateRO" select="/webcenter_page/actual_completed_date/long_date"/>
					<xsl:with-param name="className" select="'darktext_darklink_bold_12'"/>
					<xsl:with-param name="id" select="'tep_estimated'"/>	
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<!-- estimated date -->
				<xsl:choose>
				<xsl:when test="$isChangeable or /webcenter_page/estimated_date/long_date">
					<xsl:call-template name="DisplayTaskDate">
						<xsl:with-param name="isEditable" select="$isChangeable"/>
						<xsl:with-param name="langString" select="'PROJ_TASK_EXTIMATED_DATE'"/>
						<xsl:with-param name="taskDate" select="/webcenter_page/estimated_date"/>
						<xsl:with-param name="taskDateRO" select="/webcenter_page/estimated_date/long_date"/>
						<xsl:with-param name="fieldName" select="'estimated_date'"/>
						<xsl:with-param name="PeriodOfDayFieldName" select="'estimated_periodOfDay'" />
						<xsl:with-param name="className" select="'darktext_darklink_bold_12'"/>
						<xsl:with-param name="onChangeMethod" select="'window.taskExPage.pageSections.genTaskInfo.estimatedDateChanged'"/>
						<xsl:with-param name="id" select="'tep_estimated'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<!-- estimated date read-only and not specified -->
					<div class="form-group" id="tep_estimated">
						<label><xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_EXTIMATED_DATE')"/></label>
						<div class="form-entry">
							<p><i><xsl:value-of select="Lang:getStr(&lk;,'NOT_ESTIMATED')"/></i></p>
						</div>
					</div>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
			</xsl:choose>
	</xsl:template>



	<!--
		Template to show task documents details
	-->
	<xsl:template name="MainTaskDocumentsDetails">
	
		<xsl:variable name="documentsEnabled" select="/webcenter_page/project_wctask/wctask_type/documents_section/doc_section_enabled = '1'"/>
	
		<table class="table taskdocs-section">
			<thead>
				<tr>
					<th>
						<span class="add-padding-right">
							<i id="documentsDetailsMinusId" class="icon icon-normal icon-WCR_Down" onclick="window.taskExPage.pageSections.documents.slide();"/>
						</span>
						
						<span id="PROJ_TASK_DOCS">
							<xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_DOCS')"/>
						</span>
						
						<xsl:if test="$isChangeable and $documentsEnabled">
							<xsl:if test="/webcenter_page/project_wctask/wctask_type/documents_section/multi_upload_enabled = '1'">
								<a class="btn btn-default multiupload"
									href="#" 
									onclick="window.taskExPage.pageSections.documents.uploadMultipleDocsClicked();">
									<xsl:attribute name="title"><xsl:value-of select="Lang:getStr(&lk;,'MULTIUPLOAD_DOCS')"/></xsl:attribute>
									<i class="icon icon-WCR_Upload-Multi"></i>
									<xsl:value-of select="Lang:getStr(&lk;,'MULTIUPLOAD_DOCS')"/>
								</a>
							</xsl:if>
						</xsl:if>
					</th>
				</tr>
			</thead>
			<tbody>
				<tr style="display: none;" class="alwaysHidden">
					<td colspan="4">
						<textarea id="documentSourcesTextArea" cols="20" rows="4" class="form-control">
						<!--  &lt;docSources&gt;&lt;dls&gt;&lt;sourceType&gt;Browse&lt;... -->
						<xsl:value-of select="/webcenter_page/doccreation_setup_xml"/>									
						</textarea>
						<div id="documentSourcesHiddenDiv"/>
					</td>
				</tr>
				<tr>
					<td class="td-nopadding">
						<div id="documentsDetailsBlockId"/>
						<!-- Hidden input field to interchange the XML configuration with server -->
						<input type="hidden" id="DocRenderConfigXML" name="DocRenderConfigXML" value="{/webcenter_page/docrenderingsetup}"/>
					</td>
				</tr>
			</tbody>
		</table>

	</xsl:template>

	<!--
		Template to show checklist details
	-->
	<xsl:template name="MainChecklistDetails">
	
		<xsl:variable name="canChangeChecklist" select="$isAssigneeLoggedIn or ((/webcenter_page/project_wctask/wctask_type/checklist_perm_assignee_only != '1') and $changeTaskRightGranted)"/>

		<table class="table taskchecklist-section">
			<thead>
				<tr>
					<th>
						<span class="add-padding-right">
							<i id="checklistDetailsMinusId" class="icon icon-normal icon-WCR_Down" onclick="window.taskExPage.pageSections.checklist.slide();"/>
						</span>
						
						<span id="PROJ_TASK_CHECKLIST">
							<xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_CHECKLIST')"/>
						</span>
					</th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td class="td-nopadding">
						<div id="checklistDetailsBlockId">
							<xsl:call-template name="ProjectWcTaskChecklistTable">
								<xsl:with-param name="readOnly" select="not($isChangeable and $canChangeChecklist)"/>
							</xsl:call-template>
						</div>
					</td>
				</tr>
			</tbody>
		</table>

	</xsl:template>


	<!--
		Template for display of task's checklist details table
  -->
	<xsl:template name="ProjectWcTaskChecklistTable">
		<xsl:param name="readOnly"/>
		
		<div class="wcr-table" data-init="component/table/Table" data-checkbox-selector="input[name='SelectChecklistItem']">    
            <div class="wcr-table-section">
		
		<table class="ordtable">
			<thead>
				<tr>
					<th class="td-checkbox">
						<xsl:choose>
							<xsl:when test="$readOnly">#</xsl:when>
							<xsl:otherwise>
								<input type="checkbox" name="selectWholeChecklist" value="">
									<xsl:attribute name="onclick">window.taskExPage.pageSections.checklist.selectAll(this);</xsl:attribute>
								</input>
							</xsl:otherwise>
						</xsl:choose>
					</th>
					<th>
						<xsl:value-of select="Lang:getStr(&lk;, 'NAME')"/>
					</th>
					<th>
						<xsl:value-of select="Lang:getStr(&lk;, 'PROJ_TASK_COMPLETED_BY')"/>
					</th>
					<th class="td-date">
						<xsl:value-of select="Lang:getStr(&lk;, 'PROJ_TASK_COMPLETED_ON')"/>
					</th>
				</tr>
			</thead>
	
		  <!-- for templates do not display checkboxes -->
		  <tbody>
			  <xsl:for-each select="checklist/project_wctask_checklist_item">
					<tr>
						<!-- checkbox (or position number) -->
						<td class="td-checkbox">
							<xsl:choose>
							<xsl:when test="$readOnly">
								<xsl:if test="is_checked = 1">
									<input type="hidden" name="SelectChecklistItem" value="{item_id}"/>
								</xsl:if>
								<xsl:value-of select="position()"/>
							</xsl:when>
							<xsl:otherwise>
								<input type="checkbox" name="SelectChecklistItem" value="{item_id}">
									<xsl:attribute name="onclick">
										window.taskExPage.pageSections.checklist.selectItem(this, <xsl:value-of select="position()-1"/>);
									</xsl:attribute>
									<xsl:attribute name="onchange">
										window.taskExPage.pageSections.checklist.selectItem(this, <xsl:value-of select="position()-1"/>);
									</xsl:attribute>
									<xsl:if test="is_checked = 1">
										<xsl:attribute name="checked">checked</xsl:attribute>
									</xsl:if>
								</input>
							</xsl:otherwise>
							</xsl:choose>
						</td>
						
						<!--  checklist item name -->
						<td class="td-breakword">
							<xsl:value-of select="item_name"/>
						</td>
						
						<!-- operator name (user who checked the item) -->
						<td id="ChecklistUserName{position()-1}">
							<!-- content generated by ChecklistSection.generateOperatorColumn() method -->
<!--						<input type="hidden" name="ChecklistOperatorID" value="{user_operator_id}"/> -->
						</td>
						
						<!-- date when the item was checked -->
						<td id="ChecklistDate{position()-1}" class="td-date">
							<!-- content generated by ChecklistSection.generateDateColumn() method -->
<!-- 						<input type="hidden" name="ChecklistDate" value="{check_date}"/> -->
						</td>
					</tr>
			  </xsl:for-each>
		  </tbody>
		</table>
		
		</div>
		
		</div>

	</xsl:template>
	
	
	
	<!--
		Template to show task attributes details
	-->
	<xsl:template name="MainTaskAttributesDetails">
		
		<table class="table taskattrs-section">
			<thead>
				<tr>
					<th>
						<span class="add-padding-right">
							<i id="taskAttributesDetailsMinusId" class="icon icon-normal icon-WCR_Down" onclick="window.taskExPage.pageSections.attributes.slide();"/>
						</span>
						
						<span id="PROJ_TASK_SPECS">
							<xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_SPECS')"/>
						</span>
					</th>
				</tr>
			</thead>
			<tbody>
		    	<tr>
			      	<td class="td-nopadding">
			      		<div id="taskAttributesDetailsBlockId">
			        		<div id="ACatObj"></div>
			        		<div id="ACatPanel"></div>
			        	</div>
			      	</td>
			    </tr>
			</tbody>
		</table>

	</xsl:template>
	


	<!--
		Template to show discussion details
	-->
	<xsl:template name="MainDiscussionDetails">
		
		<xsl:variable name="totalMessages"
			select="task_discussion/project_wctask_thread_total_messages" />
		
		<table class="table taskdiscussion-section">
			<thead>
				<tr>
					<th>
						<span class="add-padding-right">
							<i id="discussionDetailsMinusId" class="icon icon-normal icon-WCR_Down" onclick="window.taskExPage.pageSections.discussion.slide();"/>
						</span>
						
						<span id="PROJ_TASK_DISCUSSION" class=" add-padding-right">
							<xsl:value-of select="Lang:getStr(&lk;,'PROJ_TASK_DISCUSSION_TAG')"/>
						</span>
						
						<!-- total threads in the project -->
						<span class="badge">
							<xsl:value-of select="$totalMessages" />
						</span>
						
						<!-- print action -->
						<a class="btn btn-no-border" 
							href="#" 
							onclick="window.taskExPage.pageSections.discussion.print();">
							<xsl:attribute name="title">
								<xsl:value-of select="concat(Lang:getStr(&lk;, &quot;PRINT&quot;), &quot; &quot;, Lang:getStr(&lk;, &quot;PROJ_TASK_DISCUSSION_TAG&quot;))" />
							</xsl:attribute>
							<i class="icon icon-normal icon-WCR_Print"></i>&nbsp;
						</a>
						
					</th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td>
						<xsl:variable name="discussionEnabled" select="/webcenter_page/project_wctask/wctask_type/discussions_section/discussions_enabled = '1'"/>
						<div id="discussionDetailsBlockId">
							<xsl:call-template name="ProjectWcTaskDiscussionTable">
								<xsl:with-param name="readOnly" select="not($isChangeable and $discussionEnabled)"/>
							</xsl:call-template>
						</div>
					</td>
				</tr>
			</tbody>
		</table>

	</xsl:template>


	<!-- Template for display of task's discussion details table -->
	<xsl:template name="ProjectWcTaskDiscussionTable">
		<xsl:param name="readOnly" />

		<xsl:variable name="totalMessages"
			select="task_discussion/project_wctask_thread_total_messages" />

		<!-- <input type="hidden" name="actionVal" value="AddMessage"/> -->
		<input type="hidden" name="projectThreadID"
			value="{task_discussion/project_wctask_thread_view/project_wctask_thread/@id}" />

		<!-- Data table -->
		<div>
				<xsl:for-each select="task_discussion/project_wctask_thread_message_list/project_wctask_thread_message_view">

					<table id="wctaskDiscussionMessage{position()-1}" class="table">
						<thead>
							<tr>
								<th>
									<xsl:choose>
										<xsl:when test="position() = 1">
											<xsl:value-of select="Lang:getStr(&lk;, 'STARTED_BY')" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="Lang:getStr(&lk;, 'POSTED_BY')" />
										</xsl:otherwise>
									</xsl:choose>
									&nbsp;
									<xsl:call-template name="DisplayUserName">
										<xsl:with-param name="userID" select="user/@id" />
										<xsl:with-param name="lastName" select="user/last_name" />
										<xsl:with-param name="firstName" select="user/first_name" />
										<xsl:with-param name="loginName" select="user/name" />
									</xsl:call-template>
									&nbsp;
									<xsl:value-of select="Lang:getStr(&lk;, 'ON_DATE')" />&nbsp;
									<xsl:call-template name="HumanReadableShortDateAndTime">
										<xsl:with-param name="DateString" select="project_wctask_thread_message/posted_date" />
										<xsl:with-param name="Compact" select="'true'" />
									</xsl:call-template>
								</th>
							</tr>
						</thead>
						<tbody>
							<!-- quoted message text (if any) -->
							<xsl:if test="string-length(project_wctask_thread_message/quoted_message) > 0">
								<tr>
									<td>
										&gt;<xsl:value-of select="project_wctask_thread_message/quoted_message" />
									</td>
								</tr>
							</xsl:if>

							<!-- message text -->
							<tr>
								<td>
									<xsl:value-of select="project_wctask_thread_message/message" />
								</td>
							</tr>
						</tbody>
					</table>
				</xsl:for-each>
		</div>

		<xsl:if test="($isChangeable or $canChangeAssignee) and not($readOnly)">
			<!-- if user is allowed to change the whole task or at least assignee 
				he/she can also add comments -->

			<!-- "Reply" / "Start a New Discussion" link -->
			<a id="replyInWcTaskDiscussion" 
				name="replyInWcTaskDiscussion"
				class="btn btn-default" 
				href="#" 
				onclick="window.taskExPage.pageSections.discussion.replyButtonClicked();">
				<!-- label of the link "Create Thread" or "Reply" -->
				<xsl:choose>
					<xsl:when test="$totalMessages = 0">
						<xsl:value-of select="Lang:getStr(&lk;,'NEW_THREAD')" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="Lang:getStr(&lk;,'REPLY')" />
					</xsl:otherwise>
				</xsl:choose>
			</a>
		</xsl:if>

		<!-- replay text area -->
		<div id="newDiscussionMessageBodyID" style="display:none;">
			<!-- table with text area prepared to be shown when user clicks on "Reply" 
				button -->
						<xsl:choose>
							<xsl:when test="$totalMessages = 0">
								<p><xsl:value-of select="Lang:getStr(&lk;,'THREAD_MESSAGE')" />:</p>
							</xsl:when>
							<xsl:otherwise>
								<p><xsl:value-of select="Lang:getStr(&lk;,'REPLY')" /></p>
							</xsl:otherwise>
						</xsl:choose>
						
						<textarea id="newDiscussionMessageText" name="newDiscussionMessageText" class="form-control">
							<xsl:attribute name="onkeyup">
								window.taskExPage.pageSections.discussion.modified = true;
								return imposeMaxLength(this, <xsl:value-of select="field_sizes/field_size[@key='discussion.message']/@value" />);
							</xsl:attribute>
							<xsl:attribute name="onchange">
								window.taskExPage.pageSections.discussion.modified = true; 
								return imposeMaxLength(this, <xsl:value-of select="field_sizes/field_size[@key='discussion.message']/@value" />);
							</xsl:attribute>
						</textarea>
		</div>

	</xsl:template>
	
	
	
	<!--
		Template that controls the inclusion of javascript functionality
	-->
	<xsl:template name="scriptincs">
		<xsl:call-template name="sDropEnabler"/>
		<!-- just to support "document upload from saved search" dialog -->
		<script src="javascript/documentSourceHandler.js" type="text/javascript"/>
		<script src="javascript/search.js" type="text/javascript"/>
		<script src="javascript/dynamic_homepage_utils.js" type="text/javascript"/>
		<script src="javascript/vector.js" type="text/javascript"/>
		<script src="javascript/TableSelection.js" type="text/javascript"/>
		<script src="javascript/detailswin.js" type="text/javascript"/>
		<script src="javascript/popup.js" type="text/javascript"/>
		<script src="javascript/extpopup.js" type="text/javascript"/>
		<script src="javascript/validate.js" type="text/javascript"/>
		<script src="javascript/datetools.js" type="text/javascript"/>
		<script src="javascript/webcenter_ajax.js" type="text/javascript"/>
		<script src="javascript/webcenter_xml.js" type="text/javascript"/>
		<script src="javascript/webcenter_html.js" type="text/javascript"/>
		<script src="javascript/hover.js" type="text/javascript"/>
		
		<script type="text/javascript">
			<xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>&#xA;
			// global array containing all task's documents (it's initialized in DocumentsSection.initialize() method)
			// (global variable is used in order to conform DocumentsTable.js interface)
			window.gProjectDocumentList = null; // Array to store Project Documents. Will be accessed by Documents table
			window.gProjectID; // The Id of the template or project
			window.gProjectFolders = null;   // Array containing all folders of gNewProjectID project, where logged in user can upload documents

			// make these variables a global.
			window.taskExPage = null;
			window.gExistingProjectContext = true;
			window.gDefaultFolderName = '<xsl:value-of select="XSLUtils:encodeForJScript(/webcenter_page/project_wctask/wctask_type/documents_section/task_doc_default_folder)"/>';

			// (langStrings has to be defined as global in order to conform DocumentsTable.js interface)
			window.langStrings = {
				GENERATED_WHEN_SAVED : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'GENERATED_WHEN_SAVED')"/></xsl:call-template>",
				BADPROJECTWCTASKNAME : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'BADPROJECTWCTASKNAME')"/></xsl:call-template>",
				TASK_MANUAL_START_NOT_ALLOWED_SHORT : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'TASK_MANUAL_START_NOT_ALLOWED_SHORT')"/></xsl:call-template>",
				PROJ_TASK_DUEDATE_REQUIRED : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_TASK_DUEDATE_REQUIRED')"/></xsl:call-template>",
				PROJ_TASK_DUEDATE_IN_PAST : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_TASK_DUEDATE_IN_PAST')"/></xsl:call-template>",
				NODOCSAVAIL : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'NODOCSAVAIL')"/></xsl:call-template>",
				CHECKLISTITEM_ALL_CONFIRM : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'CHECKLISTITEM_ALL_CONFIRM')"/></xsl:call-template>",
				REMOVETASKDOC_CONFIRM : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'REMOVETASKDOC_CONFIRM')"/></xsl:call-template>",
				SAVE_AND_START_WCTASK_CONFIRM : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'SAVE_AND_START_WCTASK_CONFIRM')"/></xsl:call-template>",
				SAVE_AND_COMPLETE_WCTASK_CONFIRM : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'SAVE_AND_COMPLETE_WCTASK_CONFIRM')"/></xsl:call-template>",
				PAGE_EXIT_CONFIRM : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PAGE_EXIT_CONFIRM_TEP')"/></xsl:call-template>",
				ESTIMATED_DATE_NOT_COMPLETE : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'ESTIMATED_DATE_NOT_COMPLETE')"/></xsl:call-template>",
				NO_CHANGES_MADE : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'NOCHANGESWEREMADETOTASK_TAG')"/></xsl:call-template>",
				DOCDETAILSCHECKINCOMMENT_TAG : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'DOCDETAILSCHECKINCOMMENT_TAG')"/></xsl:call-template>",
				DBERR_BAD_UPLOAD_FILE : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'DBERR_BAD_UPLOAD_FILE')"/></xsl:call-template>",
				INVALIDDOCNAMEMSG: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'INVALIDDOCNAMEMSG')"/></xsl:call-template>",
				ERRDESCRIPTIONMSG: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'ERR_UPLOAD_DESCRIPTION')"/></xsl:call-template>",
				BADCHECKINEXT: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'BADCHECKINEXT')"/></xsl:call-template>",
				WCTASK_VALIDATION_ERROR: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'WCTASK_VALIDATION_ERROR')"/></xsl:call-template>",
				WCTASK_VALIDATION_CONFIRM: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'WCTASK_VALIDATION_CONFIRM')"/></xsl:call-template>",
				
				// Strings for SDROP Role, User, Group
				ME : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_TASK_ASSIGNTOMYSELF')"/></xsl:call-template>",
				ROLE : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'ROLE')"/></xsl:call-template>",
				GROUP : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'GROUP')"/></xsl:call-template>",
				USER : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'USER')"/></xsl:call-template>",
				PM : "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJMANAGER')"/></xsl:call-template>",
										
				
				// DocumentsTable.js related
				ok: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'OK')"/></xsl:call-template>",
				cancel: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'CANCEL')"/></xsl:call-template>",
				noDocuments: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'NODOCSAVAIL')"/></xsl:call-template>",
				noProjectSelected: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_CREATION_NO_PROJ_SEL')"/></xsl:call-template>",
				loading: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_CREATION_LOADING')"/></xsl:call-template>",
				pleaseSelect: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_CREATION_SELECT')"/></xsl:call-template>",
				browse: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_CREATION_MEMBER_BROWSE')"/></xsl:call-template>",
				copy: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'COPY')"/></xsl:call-template>",
				newString: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'NEW_TAG')"/></xsl:call-template>",
				link: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_CREATION_MEMBER_LINK')"/></xsl:call-template>",
				del: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'DELETE_TAG')"/></xsl:call-template>",
				expand: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_CREATION_EXPAND')"/></xsl:call-template>",
				collapse: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_CREATION_COLLAPSE')"/></xsl:call-template>",
				rootFolder: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'ROOT_FOLDER_TAG')"/></xsl:call-template>",
				defaultFolder: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'DEFAULT_FOLDER')"/></xsl:call-template>",
				invalidCopyProjectSelected: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'SAME_COPY_PROJECT')"/></xsl:call-template>",
				namesuffix: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJ_CREATION_EDIT_FIELD')"/></xsl:call-template>",
				notAllowedDocExtension: "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'NOT_ALLOWED_DOC_EXTENSION')"/></xsl:call-template>"
			};

			// Require all the dependencies.
			require([	"pages/wctaskexecution/WcTaskExecutionPage",
						"pages/wctaskexecution/PageSection",
						"pages/wctaskexecution/AttributesSection",
						"pages/wctaskexecution/ChecklistSection",
						"pages/wctaskexecution/DiscussionSection",
						"pages/wctaskexecution/DocumentsSection",
						"pages/wctaskexecution/GeneralTaskInfoSection",
						"pages/wctaskexecution/TaskAssigneeDataProvider",
						"component/smartnames/savedsearchcontext/SavedSearchContextInfo",
						"component/smartnames/savedsearchcontext/TaskSpecificationsDynamicSmartNameCollector",
						"wcr/sdrop"
						],
						 
					function (WcTaskExecutionPage, 
								PageSection, 
								AttributesSection, 
								ChecklistSection, 
								DiscussionSection, 
								DocumentsSection, 
								GeneralTaskInfoSection, 
								TaskAssigneeDataProvider,
								SavedSearchContextInfo, 
								TaskSpecificationsDynamicSmartNameCollector) {

						var isTaskCompleted = <xsl:value-of select="$isTaskCompleted"/>;
						
				    	var currentUser = null;
				    	var canUserEditAttributes = <xsl:value-of select="$isTaskEditable"/>;
						
						<xsl:if test="/webcenter_page/project_wctask/task_type_id">
							currentUser = ObjectHandler.getCloneOfObject(window.gCurrentUser);
					    	currentUser.canEditAttributes = canUserEditAttributes;
					    	
					    	// aCatOptions will also be a global object on this page, used to init AttributeCategory.
							window.aCatOptions = new Object();
						    window.aCatOptions.ACatObj = "ACatObj";
							window.aCatOptions.isTemplate = false;
						    window.aCatOptions.ACatPanel = "ACatPanel";
						    window.aCatOptions.readURL = "GetTaskTypeLayoutXML.jsp?taskTypeID=" + '<xsl:value-of select="/webcenter_page/project_wctask/task_type_id"/>'
						    								+ "&amp;lastmodified="+'<xsl:value-of select="/webcenter_page/wctask_type/mod_time_stamp"/>';
						    window.aCatOptions.currentUser = currentUser;
						    window.aCatOptions.valuesURL = "GetAttributes.jsp?projectid="+'<xsl:value-of select="/webcenter_page/project/@id"/>'
						      						+ "&amp;tasktypeid="+'<xsl:value-of select="/webcenter_page/project_wctask/task_type_id"/>'
						     						+ "&amp;taskid="+'<xsl:value-of select="/webcenter_page/project_wctask/@id"/>'; 						     						
						    window.aCatOptions.projectAttributeValuesURL = "GetAttributes.jsp?projectid="+'<xsl:value-of select="/webcenter_page/project/@id"/>';
						    window.aCatOptions.defaultHourAsHalfHours = <xsl:value-of select="/webcenter_page/default_due_date_time"/>;
						    window.aCatOptions.isTaskTypePage = true;
						    window.aCatOptions.autoUpdateProjAttrsCheckbox = <xsl:value-of select="/webcenter_page/project_wctask/wctask_type/auto_update_project_attributes"/>;

							if (isTaskCompleted) {
						    	// this prevents the automatic updating of empty task specifications from project attributes
						    	// when the task is already completed! 
						    	window.aCatOptions.autoUpdateProjAttrsCheckbox = false;
						    }
					    	window.aCatOptions.type = "task";
					    	window.aCatOptions.projectID = '<xsl:value-of select="/webcenter_page/project/@id"/>';
					    	window.aCatOptions.taskID = '<xsl:value-of select="/webcenter_page/project_wctask/@id"/>';
				  		</xsl:if>
				  		
				  		
				  		// part of interface translation between task execution page and DocumentsTable.js
						window.slide = function(BlockId, img, show)	{
							window.taskExPage.pageSections.documents.slide();
						}
				  		
						function initializeWcTaskExecutionPage() {
							try {
							
							// prepare general data used within the whole task execution page and create its instance
							// ======================================================================================
							<xsl:variable name="userName">
								<xsl:call-template name="DisplayUserName">
									<xsl:with-param name="lastName" select="/webcenter_page/loginuserlastname"/>
									<xsl:with-param name="firstName" select="/webcenter_page/loginuserfirstname"/>
									<xsl:with-param name="loginName" select="/webcenter_page/loginuser"/>
								</xsl:call-template>
							</xsl:variable>
							
							var generalData = {
								taskID : '<xsl:value-of select="/webcenter_page/project_wctask/@id"/>',
								projectID : '<xsl:value-of select="/webcenter_page/project_wctask/project_id"/>',
								loggedInUserID : '<xsl:value-of select="/webcenter_page/loginuserid"/>',
								loggedInUserFullName : '<xsl:value-of select="XSLUtils:encodeForJScript($userName)"/>',
								isProjectActive : <xsl:value-of select="$isProjActive"/>,
								isTaskEditable : <xsl:value-of select="$isTaskEditable"/>,
								isChangeable : <xsl:value-of select="$isChangeable"/>,
								isStatusEditable : <xsl:value-of select="$isStatusEditable"/>,
								canChangeAssignee : <xsl:value-of select="$canChangeAssignee"/>,
								isTaskStarted : <xsl:value-of select="$isTaskStarted"/>,
								isTaskCompleted : isTaskCompleted,
								
								// variable for debug purposes - fast switch between task execution and editation modes
								taskExecution : <xsl:value-of select="$taskExecution"/>
							};
							
							// create instance of task execution page
							var taskExPage = new WcTaskExecutionPage(generalData, langStrings);
			
			
							// prepare data and create instance of task's general info section
							// ===============================================================
							var genTaskInfoData = {
								allowManualStart : "<xsl:value-of select="/webcenter_page/project_wctask/allow_manual_start"/>",
								origTaskStatusID : "<xsl:value-of select="/webcenter_page/project_wctask/status/@id"/>",
								origDueDateMS : parseInt("<xsl:value-of select="/webcenter_page/due_date/long_date"/>")
							};
							
							// add task general info section to task execution page
							var genTaskInfoSection = new GeneralTaskInfoSection("mainWcTaskInfoRowId", "taskDetailsBlockId", genTaskInfoData);
							taskExPage.addSection(genTaskInfoSection, "genTaskInfo");
							
							
							// prepare data and create instance of task's documents section
							// ============================================================
							var documentsData = {
								enabled : <xsl:value-of select="/webcenter_page/project_wctask/wctask_type/documents_section/doc_section_enabled = '1'"/>,
								docsNumber : parseInt("<xsl:value-of select="count(/webcenter_page/project_wctask_document_list/project_wctask_doc_version)"/>"),
								taskTypeName : '<xsl:value-of select="XSLUtils:encodeForJScript(/webcenter_page/project_wctask/task_type_name)"/>',
								projectID : '<xsl:value-of select="/webcenter_page/project_wctask/project_id"/>',
								showThumbnails : <xsl:value-of select="not(/webcenter_page/show_thumbnails = '0')"/>,
								defTaskDocAttrCatID : '<xsl:value-of select="/webcenter_page/wctask_type_list/wctask_type_view/wctask_type/documents_section/def_doc_attrs_cat_id"/>',
								defTaskDocFolderName : window.gDefaultFolderName,
								
								// array of documents already linked to the task
								docList : [
								<xsl:for-each select="/webcenter_page/project_wctask_document_list/project_wctask_doc_version">
									{
										deleted : false,
										id : '<xsl:value-of select="document_id"/>',
										docverid : '<xsl:value-of select="@id"/>',
										revision_letter : '<xsl:value-of select="revision_letter"/>',
										name : '<xsl:value-of select="XSLUtils:encodeForJScript(original_disk_filename)"/>',
										description : '<xsl:value-of select="XSLUtils:encodeForJScript(document/description)"/>',
										categoryid : '<xsl:value-of select="category_id"/>'
									}
									<xsl:if test="position()!=last()">,</xsl:if>
								</xsl:for-each>
								]
							};
							
							
//JANH TODO!!! consider adding the loading of saved searches to AJAXDataCache.js!
							<!-- generate array of global document saved searches configured in the system -->
							documentsData.docSavedSearchNameList = new Array(
								<xsl:for-each select="/webcenter_page/global_saved_search_list/saved_search">
									<xsl:sort select="name" order="ascending"/>
									<xsl:if test="not(type='project_search' or type='wctask_search')">
										<!-- when type of the global saved search is something else than project or wctask search -->
										<!-- (The condition is done this way, because we have multiple document search types...) -->
										"<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="name"/></xsl:call-template>",
									</xsl:if>
								</xsl:for-each>
								"lastElement"
							);
							documentsData.docSavedSearchNameList.pop();   // remove the "lastElement" from the generated array
							
							
							// add task documents section to task execution page
							var documentsSection = new DocumentsSection("mainDocumentsDetailsRowId", "documentsDetailsMinusId", "documentsDetailsBlockId", documentsData, "SHOW");
							taskExPage.addSection(documentsSection, "documents");
							
							
							// prepare data and create instance of task's checklist section
							// ============================================================
							var checklistData = {
								itemsNumber : parseInt('<xsl:value-of select="count(/webcenter_page/checklist/project_wctask_checklist_item)"/>'),
								items : [
								<xsl:for-each select="/webcenter_page/checklist/project_wctask_checklist_item">
									<xsl:variable name="operatorName">
										<xsl:call-template name="DisplayUserName">
											<xsl:with-param name="lastName" select="user/last_name"/>
											<xsl:with-param name="firstName" select="user/first_name"/>
											<xsl:with-param name="loginName" select="user/name"/>
										</xsl:call-template>						
									</xsl:variable>
									{
										id : '<xsl:value-of select="item_id"/>',
										operatorID : '<xsl:value-of select="user_operator_id"/>',
										operatorFullName : '<xsl:value-of select="XSLUtils:encodeForJScript($operatorName)"/>',
										checked : <xsl:value-of select="is_checked = '1'"/>,
										checkDate : parseInt('<xsl:value-of select="check_date"/>')
									}
									<xsl:if test="position()!=last()">,</xsl:if>
								</xsl:for-each>
								]
							};
			
							// add task checklist section to task execution page
							var checklistSection = new ChecklistSection("mainChecklistDetailsRowId", "checklistDetailsMinusId", "checklistDetailsBlockId", checklistData, "SHOW");
							taskExPage.addSection(checklistSection, "checklist");
			
							
							// prepare data and create instance of task's attributes (specifications) section
							// ==============================================================================
							var attributesData = {
								attrsNumber : parseInt("<xsl:value-of select="/webcenter_page/total_task_attributes"/>")
							};
							
							if(attributesData.attrsNumber === 0){
								$("#mainTableId > div").not("#upperButtonRow").removeClass("displayNone");
								$("#LoadingRowId").remove();
							}
							
							// add task attributes (specifications) section to task execution page
							var attributesSection = new AttributesSection("mainAttributesDetailsRowId", "taskAttributesDetailsMinusId", "taskAttributesDetailsBlockId", attributesData, "SHOW");
							taskExPage.addSection(attributesSection, "attributes");
			
			
							// prepare data and create instance of task's discussion section
							// =============================================================
							<xsl:variable name="msgNumber">	
								<xsl:choose>
									<xsl:when test="/webcenter_page/project_wctask/wctask_type/discussions_section/discussions_enabled = '1'">
										<xsl:value-of select="/webcenter_page/task_discussion/project_wctask_thread_total_messages"/>
									</xsl:when>
									<xsl:otherwise><xsl:value-of select="'0'"/></xsl:otherwise>
								</xsl:choose>
							</xsl:variable>
							
							var discussionData = {
								enabled : <xsl:value-of select="/webcenter_page/project_wctask/wctask_type/discussions_section/discussions_enabled = '1'"/>,
								msgNumber : parseInt("<xsl:value-of select="$msgNumber"/>"),
								threadID : "<xsl:value-of select="/webcenter_page/task_discussion/project_wctask_thread_view/project_wctask_thread/@id"/>"
							};
							
							// add task discussion section to task execution page
							var discussionSection = new DiscussionSection("mainDiscussionDetailsRowId", "discussionDetailsMinusId", "discussionDetailsBlockId", discussionData, "SHOW");
							taskExPage.addSection(discussionSection, "discussion");
							
							var assigneeSDrop ;
							if ($("#taskAssigneeSDrop").length>0){
								// Task Assignee SDrop
								 
								var dataProviderURL = 'GetPotentialTaskAssignees.jsp?projectid='+'<xsl:value-of select="/webcenter_page/project/@id"/>'+ 
												'&amp;taskid='+'<xsl:value-of select="/webcenter_page/project_wctask/@id"/>'+
												'&amp;mainassigneeid='+'<xsl:value-of select="/webcenter_page/project_wctask/main_assignee_id"/>'+
												'&amp;currentuservalidassignee='+ <xsl:value-of select="/webcenter_page/cur_user_would_be_valid_owner"/> ; 
								var taskAssigneeDP = new TaskAssigneeDataProvider({dataSource : dataProviderURL, langArr: window.langStrings });
								
								assigneeSDrop = new SDrop($("#taskAssigneeSDrop"), null, taskAssigneeDP, {
	           						 manageStyleAndWidth: false,
	           						 minWidth : 800,
	           						 autoload : false ,
	           						 autoloadOnFirstUsage: true,
	           						 sort : true,
	           						 flushCacheOnLoad: true
	           					});
	           					
							}
							taskExPage.setSDrop(assigneeSDrop);
							
							// Check if expand/collapse should be hidden
							checkExpand();
							
							return taskExPage;
							
							}
							catch (err) {
								alert("Problem in initializeWcTaskExecutionPage() function: " + err);
							}
						}

						// on page load
						$(document).ready(function() {
							window.taskExPage = initializeWcTaskExecutionPage();
							window.taskExPage.show();	
							window.taskExPage.registerEventToDetectChanges();
						});
						
				  	}
				);
			
			
			<xsl:text disable-output-escaping="yes">//--&gt;</xsl:text>&#xA;
		</script>
		<xsl:call-template name="DateJavaScript"/>
		<xsl:call-template name="doctemplatesJavaScript"/>
	</xsl:template>

</xsl:stylesheet>
	
